package bou.amine.apps.readerforselfossv2.android.tests.robolectric

import android.view.View
import bou.amine.apps.readerforselfossv2.android.HomeActivity
import bou.amine.apps.readerforselfossv2.android.R
import bou.amine.apps.readerforselfossv2.service.ACRASettings
import bou.amine.apps.readerforselfossv2.service.AppSettingsService.Companion.BASE_URL
import bou.amine.apps.readerforselfossv2.service.AppSettingsService.Companion.LOGIN
import bou.amine.apps.readerforselfossv2.service.AppSettingsService.Companion.PASSWORD
import io.mockk.every
import io.mockk.mockk
import org.junit.Assert.assertEquals
import org.junit.Assert.assertNotNull
import org.junit.Assert.assertTrue
import org.junit.Before
import org.junit.Test
import org.junit.runner.RunWith
import org.robolectric.Robolectric
import org.robolectric.Shadows

@RunWith(RobotElectriqueRunnerclass::class)
class HomeActivityTest {


    @Before
    fun setUp() {
        val settings = mockk<ACRASettings>()
        every { settings.getString(PASSWORD, "") } returns ""
        every { settings.getString(LOGIN, "") } returns ""
        every { settings.getString(BASE_URL, "") } returns "http://10.0.2.2:8888"
    }

    @Test
    fun testMenu() {
        Robolectric.buildActivity(HomeActivity::class.java).use { controller ->
            controller.setup() // Moves the Activity to the RESUMED state

            val activity = controller.get()
            val searchMenuItem = activity.findViewById<View>(R.id.action_search)
            try {
                assertNotNull(searchMenuItem)
                assertTrue(searchMenuItem.visibility == View.VISIBLE)
                assertTrue(searchMenuItem.isClickable)

                val filterMenuItem = activity.findViewById<View>(R.id.action_filter)
                assertNotNull(filterMenuItem)
                assertTrue(filterMenuItem.visibility == View.VISIBLE)
                assertTrue(filterMenuItem.isClickable)

                // Simulate opening the options menu
                Shadows.shadowOf(activity)
                    .clickMenuItem(R.id.action_search) // or R.id.action_filter, ...

                // Assert menu items are displayed
                // You'll need to find the menu items using Robolectric APIs
                // and assert their visibility, for example:
                // val readAllMenuItem = Shadows.shadowOf(activity).optionsMenu.findItem(R.id.readAll)
                // assertNotNull(readAllMenuItem)
                // assertTrue(readAllMenuItem.isVisible)
            } catch (e: Throwable) {
                val screenshot = Screenshot.takeScreenshot(activity)
                screenshot.save(File("screenshots"), "myTestFailure")
                throw e
            }
        }
    }

    @Test
    fun testMenuActions() {
        // Simulate menu item clicks and assert the expected behavior
        // using Robolectric APIs, for example:
        // Shadows.shadowOf(activity).clickMenuItem(R.id.action_search)
        // val searchEditText = activity.findViewById<EditText>(R.id.search_src_text)
        // assertTrue(searchEditText.hasFocus())
    }

    @Test
    fun testEmptyView() {
        Robolectric.buildActivity(HomeActivity::class.java).use { controller ->
            controller.setup() // Moves the Activity to the RESUMED state

            val activity = controller.get()
            val emptyView = activity.findViewById<View>(R.id.emptyText)
            assertNotNull(emptyView)
            assertEquals(View.VISIBLE, emptyView.visibility)

            // Assert bottom bar items
            // You'll need to find the bottom bar items using Robolectric APIs
            // and assert their visibility and selection state, for example:
            // val newTabItem = activity.findViewById<View>(R.id.tab_new)
            // assertTrue(newTabItem.isSelected)
        }
    }
}